==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ImageSourcePathFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ImageSourcePathFluentImpl<A extends io.fabric8.openshift.api.model.ImageSourcePathFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ImageSourcePathFluent<A>{
  public ImageSourcePathFluentImpl() {
  }
  public ImageSourcePathFluentImpl(io.fabric8.openshift.api.model.ImageSourcePath instance) {
    this.withDestinationDir(instance.getDestinationDir()); 
    this.withSourcePath(instance.getSourcePath()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String destinationDir;
  private java.lang.String sourcePath;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDestinationDir() {
    return this.destinationDir;
  }
  public A withDestinationDir(java.lang.String destinationDir) {
    this.destinationDir=destinationDir; return (A) this;
  }
  public java.lang.Boolean hasDestinationDir() {
    return this.destinationDir != null;
  }
  
  /**
   * Method is deprecated. use withDestinationDir instead.
   */
  @java.lang.Deprecated
  public A withNewDestinationDir(java.lang.String arg0) {
    return (A)withDestinationDir(new String(arg0));
  }
  public java.lang.String getSourcePath() {
    return this.sourcePath;
  }
  public A withSourcePath(java.lang.String sourcePath) {
    this.sourcePath=sourcePath; return (A) this;
  }
  public java.lang.Boolean hasSourcePath() {
    return this.sourcePath != null;
  }
  
  /**
   * Method is deprecated. use withSourcePath instead.
   */
  @java.lang.Deprecated
  public A withNewSourcePath(java.lang.String arg0) {
    return (A)withSourcePath(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageSourcePathFluentImpl that = (ImageSourcePathFluentImpl) o;
    if (destinationDir != null ? !destinationDir.equals(that.destinationDir) :that.destinationDir != null) return false;
    if (sourcePath != null ? !sourcePath.equals(that.sourcePath) :that.sourcePath != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(destinationDir,  sourcePath,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ImageSourcePathFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ImageSourcePathFluentImpl<A extends io.fabric8.openshift.api.model.ImageSourcePathFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ImageSourcePathFluent<A>{
  public ImageSourcePathFluentImpl() {
  }
  public ImageSourcePathFluentImpl(io.fabric8.openshift.api.model.ImageSourcePath instance) {
    this.withDestinationDir(instance.getDestinationDir()); 
    this.withSourcePath(instance.getSourcePath()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String destinationDir;
  private java.lang.String sourcePath;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDestinationDir() {
    return this.destinationDir;
  }
  public A withDestinationDir(java.lang.String destinationDir) {
    this.destinationDir=destinationDir; return (A) this;
  }
  public java.lang.Boolean hasDestinationDir() {
    return this.destinationDir != null;
  }
  
  /**
   * Method is deprecated. use withDestinationDir instead.
   */
  @java.lang.Deprecated
  public A withNewDestinationDir(java.lang.String arg0) {
    return (A)withDestinationDir(new String(arg0));
  }
  public java.lang.String getSourcePath() {
    return this.sourcePath;
  }
  public A withSourcePath(java.lang.String sourcePath) {
    this.sourcePath=sourcePath; return (A) this;
  }
  public java.lang.Boolean hasSourcePath() {
    return this.sourcePath != null;
  }
  
  /**
   * Method is deprecated. use withSourcePath instead.
   */
  @java.lang.Deprecated
  public A withNewSourcePath(java.lang.String arg0) {
    return (A)withSourcePath(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageSourcePathFluentImpl that = (ImageSourcePathFluentImpl) o;
    if (destinationDir != null ? !destinationDir.equals(that.destinationDir) :that.destinationDir != null) return false;
    if (sourcePath != null ? !sourcePath.equals(that.sourcePath) :that.sourcePath != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(destinationDir,  sourcePath,  additionalProperties,  super.hashCode());
  }
  
}
